// Copyright (C) 2014 - Michael Baudin
//
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt


function x=distfun_histornd(varargin)
    // Histogram random numbers
    //  
    // Calling Sequence
    //   x=distfun_histornd(h)
    //   x=distfun_histornd(h,[m,n])
    //   x=distfun_histornd(h,m,n)
    //
    // Parameters
    // h : an histogram object
    // m : a 1-by-1 matrix of floating point integers, the number of rows of x
    // n : a 1-by-1 matrix of floating point integers, the number of columns of x
    // x: a matrix of doubles, the random numbers.
    //
    // Description
    // Generates random variables from the Histogram distribution function.
    //
    // The h object must be created with distfun_histocreate.
    //
    // Examples
    // m=1000;
    // data=distfun_normrnd(0,1,m,1);
    // h=distfun_histocreate("data",data);
    // x=distfun_histornd(h,1000,1);
    // scf();
    // histplot(10,x)
    // x = linspace(-4,4);
    // y=distfun_histopdf(x,h);
    // plot(x,y,"b-")
    // legend(["Histogram","Exact"]);
    // xtitle("Histogram")
    // xlabel("x")
    // ylabel("Density")
    //
    // Authors
    // Copyright (C) 2014 - Michael Baudin

    // Load Internals lib
    select nargin
    case 2
        h = varargin(1);
        v = varargin(2);
        x = %distfun_histornd1(h, v);
    case 3
        x = %distfun_histornd2(varargin(:));
    else
        error(msprintf(gettext("%s: Wrong number of input argument.\n"),"distfun_histornd"));
    end
endfunction

function x = %distfun_histornd1(h, v)
    arguments
        h {mustBeA(h, "struct")}
        v {mustBeA(v, "double"), mustBeVector, mustBeInteger, mustBeGreaterThanOrEqual(v, 0)}
    end
    u=distfun_unifrnd(0,1,v(1),v(2))
    x=distfun_histoinv(u,h)
end

function x = %distfun_histornd2(h, m, n)
    arguments
        h {mustBeA(h, "struct")}
        m {mustBeA(m, "double"), mustBeScalar, mustBeInteger, mustBeGreaterThanOrEqual(m, 0)}
        n {mustBeA(n, "double"), mustBeScalar, mustBeInteger, mustBeGreaterThanOrEqual(n, 0)}
    end
    u=distfun_unifrnd(0,1,m, n)
    x=distfun_histoinv(u,h)
end